@@ -1,16 +1,16 @@
 """Base Class for all CalibrationInfo objects."""
 import json
 from dataclasses import dataclass, fields, asdict
-from distutils.version import StrictVersion
 from pathlib import Path
 from typing import Tuple, Union, TypeVar, ClassVar, Optional, Type, Iterable
 
 import numpy as np
 import pandas as pd
+from packaging.version import Version
 
 CalInfo = TypeVar("CalInfo", bound="CalibrationInfo")
 
-_CAL_FORMAT_VERSION = StrictVersion("2.0.0")
+_CAL_FORMAT_VERSION = Version("2.0.0")
 
 
 @dataclass(eq=False)
@@ -29,7 +29,7 @@ class CalibrationInfo:
 
     """
 
-    CAL_FORMAT_VERSION: ClassVar[StrictVersion] = _CAL_FORMAT_VERSION  # noqa: invalid-name
+    CAL_FORMAT_VERSION: ClassVar[Version] = _CAL_FORMAT_VERSION  # noqa: invalid-name
     CAL_TYPE: ClassVar[str] = None  # noqa: invalid-name
     acc_unit: Optional[str] = None
     gyr_unit: Optional[str] = None
@@ -179,13 +179,13 @@ class CalibrationInfo:
             return cls
         try:
             out_cls = next(x for x in cls._get_subclasses() if x.CAL_TYPE == cal_type)
-        except StopIteration:
+        except StopIteration as e:
             raise ValueError(
                 "No suitable calibration info class could be found for caltype `{}`. "
                 "The following classes were checked: {}. "
                 "If your CalibrationInfo class is missing, make sure it is imported before loading a "
                 "file.".format(cal_type, (cls.__name__, *(x.__name__ for x in cls._get_subclasses())))
-            )
+            ) from e
         return out_cls
 
     def to_json(self) -> str:
@@ -210,7 +210,7 @@ class CalibrationInfo:
 
         """
         raw_json = json.loads(json_str)
-        check_cal_format_version(StrictVersion(raw_json.pop("_format_version", None)), cls.CAL_FORMAT_VERSION)
+        check_cal_format_version(Version(raw_json.pop("_format_version", None)), cls.CAL_FORMAT_VERSION)
         subclass = cls.find_subclass_from_cal_type(raw_json.pop("cal_type"))
         return subclass._from_list_dict(raw_json)
 
@@ -224,7 +224,7 @@ class CalibrationInfo:
 
         """
         data_dict = self._to_list_dict()
-        return json.dump(data_dict, open(path, "w"), cls=NumpyEncoder, indent=4)
+        return json.dump(data_dict, open(path, "w", encoding="utf8"), cls=NumpyEncoder, indent=4)
 
     @classmethod
     def from_json_file(cls: Type[CalInfo], path: Union[str, Path]) -> CalInfo:
@@ -242,7 +242,7 @@ class CalibrationInfo:
             The exact child class is determined by the `cal_type` key in the json string.
 
         """
-        with open(path, "r") as f:
+        with open(path, "r", encoding="utf8") as f:
             raw_json = json.load(f)
         check_cal_format_version(raw_json.pop("_format_version", None), cls.CAL_FORMAT_VERSION)
         subclass = cls.find_subclass_from_cal_type(raw_json.pop("cal_type"))
@@ -287,11 +287,18 @@ class CalibrationInfo:
         with h5py.File(path, "r") as hdf:
             format_version = hdf.get("_format_version")
             if format_version:
-                format_version = format_version[()]
+                format_version = format_version.asstr()[()]  # type: ignore
             check_cal_format_version(format_version, cls.CAL_FORMAT_VERSION)
-            subcls = cls.find_subclass_from_cal_type(hdf["cal_type"][()])
-            data = {k.name: hdf.get(k.name)[()] for k in fields(subcls)}
-
+            subcls = cls.find_subclass_from_cal_type(hdf["cal_type"][()].decode("utf-8"))
+            data = {}
+            for k in fields(subcls):
+                dp = hdf.get(k.name)
+                if h5py.check_string_dtype(dp.dtype):
+                    # String data
+                    data[k.name] = dp.asstr()[()]
+                else:
+                    # No string data
+                    data[k.name] = dp[()]
         return subcls._from_list_dict(data)
 
 
@@ -304,15 +311,13 @@ class NumpyEncoder(json.JSONEncoder):
         return json.JSONEncoder.default(self, obj)
 
 
-def check_cal_format_version(
-    version: Optional[StrictVersion] = None, current_version: StrictVersion = _CAL_FORMAT_VERSION
-):
+def check_cal_format_version(version: Optional[Version] = None, current_version: Version = _CAL_FORMAT_VERSION):
     """Check if a calibration can be loaded with the current loader."""
     # No version means, the old 1.0 format is used that does not provide a version string
     if not version:
-        version = StrictVersion("1.0.0")
+        version = Version("1.0.0")
     if isinstance(version, str):
-        version = StrictVersion(version)
+        version = Version(version)
 
     if version == current_version:
         return
